pub struct LinkNode<T: Copy> {
pub next: *mut LinkNode<T>,
pub prev: *mut *mut LinkNode<T>,
pub data: T,
}Expand description
Fields
next: *mut LinkNode<T>Pointing the next node. If this is the last node, the field will be null.
prev: *mut *mut LinkNode<T>Pointing the previous node’s next field. If this is the first node,
the field will point to the head’s head field.
data: TThe data stored in the link list, with the type T.
Implementations